@@ -1,14 +1,19 @@
 # this is a test summary for using the vcov matrix
 # it should replace  he old summary.gamlss
 #---------------------------------------------------------------------------------------
-summary.gamlss<- function (object, type = c("vcov", "qr"), save = FALSE, ...) 
+summary.gamlss<- function (object,
+                           type = c("vcov", "qr"), robust = FALSE,
+                           save = FALSE, 
+                    hessian.fun = c("R", "PB"), 
+                         digits = max(3, getOption("digits") - 3),
+                           ...) 
 {
 type <- match.arg(type)
 ## if use the vcov for se's
 if (type=="vcov")
  {
 ## this will be moved  
-      covmat <- try(vcov(object,"all"), silent = TRUE) 
+      covmat <- try(suppressWarnings(vcov(object, type="all", robust=robust,  hessian.fun = hessian.fun)), silent = TRUE) 
              if (any(class(covmat)%in%"try-error"||any(is.na(covmat$se))))
                  { 
                    warning(paste("summary: vcov has failed, option qr is used instead\n"))
@@ -16,7 +21,8 @@ if (type=="vcov")
                  }
 ## if try fails call old summary
  }      
-if (type=="vcov")
+ifWarning <- rep(FALSE, length(object$parameters))# to create warnings
+if (type=="vcov")#  type vcov --------------------------------------------------
  {
         coef <- covmat$coef
           se <- covmat$se
@@ -25,8 +31,9 @@ if (type=="vcov")
   coef.table <- cbind(coef, se, tvalue, pvalue)
   dimnames(coef.table) <- list(names(coef), c("Estimate" , "Std. Error" ,"t value","Pr(>|t|)"))  
 #now the table contains all informatio I need 
+#browser()
+#printCoefmat(coef.table, digits = digits, signif.stars = TRUE)
 # to print use   coef.table[1:3,] 
-      digits <- max(3, getOption("digits") - 3)
       cat("*******************************************************************")
     cat("\nFamily: ", deparse(object$family), "\n") 
     cat("\nCall: ", deparse(object$call),  "\n", fill=TRUE)
@@ -36,6 +43,9 @@ if (type=="vcov")
 #================ mu ESTIMATES ========================
     if ("mu"%in%object$parameters)   
     {
+      
+      ifWarning[1]  <- (!is.null(unlist(attr(terms(formula(object, "mu"), 
+                  specials = .gamlss.sm.list), "specials")))) 
         if (object$mu.df != 0)   
         {          
                         pm <- object$mu.qr$rank 
@@ -48,7 +58,8 @@ if (type=="vcov")
                 cat("  [contrasts: ", apply(cbind(names(co), co), 1, 
                     paste, collapse = "="), "]")
             cat("\n")
-            print.default(coef.table[p1,], digits = digits, print.gap = 2, quote = FALSE)
+            printCoefmat(coef.table[p1,,drop=FALSE], digits = digits, signif.stars = TRUE)
+     #       print.default(coef.table[p1,], digits = digits, print.gap = 2, quote = FALSE)
             cat("\n")
         }
         else
@@ -65,6 +76,8 @@ if (type=="vcov")
     }
     if ("sigma"%in%object$parameters) 
     {
+      ifWarning[2]  <- (!is.null(unlist(attr(terms(formula(object, "sigma"), 
+                     specials = .gamlss.sm.list), "specials")))) 
          if (object$sigma.df != 0)   
         {
                      ps <- object$sigma.qr$rank 
@@ -74,8 +87,9 @@ if (type=="vcov")
         cat("Sigma link function: ", object$sigma.link)
         cat("\n")
         cat("Sigma Coefficients:")
-        cat("\n")
-        print.default(coef.table[p1,], digits = digits, print.gap = 2,  quote = FALSE)
+        cat("\n")    
+        printCoefmat(coef.table[p1,, drop=FALSE], digits = digits, signif.stars = TRUE)
+       # print.default(coef.table[p1,], digits = digits, print.gap = 2,  quote = FALSE)
         cat("\n")
         }
         else 
@@ -92,6 +106,8 @@ if (type=="vcov")
     }
     if ("nu"%in%object$parameters) 
     {
+      ifWarning[3]  <- (!is.null(unlist(attr(terms(formula(object, "nu"), 
+                      specials = .gamlss.sm.list), "specials")))) 
          if (object$nu.df != 0)   
         {
                    
@@ -101,7 +117,8 @@ if (type=="vcov")
         cat("Nu link function: ", object$nu.link,"\n")
         cat("Nu Coefficients:")
         cat("\n")
-        print.default(coef.table[p1,], digits = digits, print.gap = 2,  quote = FALSE)
+        printCoefmat(coef.table[p1,, drop=FALSE], digits = digits, signif.stars = TRUE)
+       # print.default(coef.table[p1,], digits = digits, print.gap = 2,  quote = FALSE)
         cat("\n")
         }
         else
@@ -117,6 +134,8 @@ if (type=="vcov")
     }
     if ("tau"%in%object$parameters) 
     {
+      ifWarning[4]  <- (!is.null(unlist(attr(terms(formula(object, "tau"), 
+                     specials = .gamlss.sm.list), "specials")))) 
          if (object$tau.df != 0)   
         {
                     
@@ -126,7 +145,8 @@ if (type=="vcov")
         cat("Tau link function: ", object$tau.link,"\n")
         cat("Tau Coefficients:")
         cat("\n")
-        print.default(coef.table[p1,], digits = digits, print.gap = 2,  quote = FALSE)
+        printCoefmat(coef.table[p1,, drop=FALSE], digits = digits, signif.stars = TRUE)
+       # print.default(coef.table[p1,], digits = digits, print.gap = 2,  quote = FALSE)
         cat("\n")
         }
         else
@@ -140,6 +160,13 @@ if (type=="vcov")
                 cat("Tau is equal with the vector (", object$tau.fv[1], ",",object$tau.fv[2], ",",object$tau.fv[3], ",",object$tau.fv[4], ", ...) \n")
             }
     }
+if (any(ifWarning))
+{
+  cat("-------------------------------------------------------------------\n")
+  cat("NOTE: Additive smoothing terms exist in the formulas: \n")
+  cat(" i) Std. Error for smoothers are for the linear effect only. \n")
+  cat("ii) Std. Error for the linear terms maybe are not accurate. \n")
+}
    cat("-------------------------------------------------------------------\n")
    cat("No. of observations in the fit: ", object$noObs, "\n")
    cat("Degrees of Freedom for the fit: ", object$df.fit)
@@ -151,10 +178,11 @@ if (type=="vcov")
         "\n            SBC:    ",object$sbc, "\n") #format(signif(object$sbc, digits)), "\n")
     cat("*******************************************************************")
     cat("\n")
-  }  
-else
+  } 
+if (type=="qr")#     TYPE qr ---------------------------------------------------
   {
-# function definition  
+# local function definition
+#-------------------------------------------------------------------------------
         estimatesgamlss<-function (object,Qr, p1, coef.p, est.disp , df.r, digits = max(3, getOption("digits") - 3),
                                                covmat.unscaled , ...)
           {
@@ -185,9 +213,11 @@ else
                            }
                           return(coef.table)
           }
+##------------------------------------------------------------------------------
 # here for the proper function
+##------------------------------------------------------------------------------
       dispersion <- NULL
-      digits <- max(3, getOption("digits") - 3)
+ #     digits <- max(3, getOption("digits") - 3)
       cat("*******************************************************************")
     cat("\nFamily: ", deparse(object$family), "\n") 
       cat("\nCall: ", deparse(object$call),  "\n", fill=TRUE)
@@ -197,6 +227,8 @@ else
 #================ mu ESTIMATES ========================
     if ("mu"%in%object$parameters)   
     {
+      ifWarning[1]  <- (!is.null(unlist(attr(terms(formula(object, "mu"), 
+                             specials = .gamlss.sm.list), "specials")))) 
         if (object$mu.df != 0)   
         {
             Qr <- object$mu.qr 
@@ -229,7 +261,8 @@ else
                 cat("  [contrasts: ", apply(cbind(names(co), co), 1, 
                     paste, collapse = "="), "]")
             cat("\n")
-            print.default(mu.coef.table, digits = digits, print.gap = 2, quote = FALSE)
+            printCoefmat(mu.coef.table, digits = digits, signif.stars = TRUE)
+           # print.default(mu.coef.table, digits = digits, print.gap = 2, quote = FALSE)
             cat("\n")
         }
         else
@@ -244,6 +277,7 @@ else
             else
                 cat("Mu is equal with the vector (", object$mu.fv[1], ",",object$mu.fv[2], ",",object$mu.fv[3], ",",object$mu.fv[4], ", ...) \n")
             }
+        coef.table <- mu.coef.table
     }
     else
     {
@@ -256,6 +290,8 @@ else
     }
     if ("sigma"%in%object$parameters) 
     {
+      ifWarning[2]  <- (!is.null(unlist(attr(terms(formula(object, "sigma"), 
+                        specials = .gamlss.sm.list), "specials")))) 
          if (object$sigma.df != 0)   
         {
                       Qr <- object$sigma.qr 
@@ -273,7 +309,8 @@ else
         cat("\n")
         cat("Sigma Coefficients:")
         cat("\n")
-        print.default(sigma.coef.table, digits = digits, print.gap = 2,  quote = FALSE)
+        printCoefmat(sigma.coef.table, digits = digits, signif.stars = TRUE)
+        #print.default(sigma.coef.table, digits = digits, print.gap = 2,  quote = FALSE)
         cat("\n")
         }
         else 
@@ -286,9 +323,12 @@ else
             else
                 cat("Sigma is equal with the vector (", object$sigma.fv[1], ",",object$sigma.fv[2], ",",object$sigma.fv[3], ",",object$sigma.fv[4], ", ...) \n")
             }
+         coef.table <- rbind(mu.coef.table, sigma.coef.table)
     }
     if ("nu"%in%object$parameters) 
     {
+      ifWarning[3]  <- (!is.null(unlist(attr(terms(formula(object, "nu"), 
+                             specials = .gamlss.sm.list), "specials")))) 
          if (object$nu.df != 0)   
         {
                      Qr <- object$nu.qr 
@@ -304,7 +344,8 @@ else
         cat("Nu link function: ", object$nu.link,"\n")
         cat("Nu Coefficients:")
         cat("\n")
-        print.default(nu.coef.table, digits = digits, print.gap = 2,  quote = FALSE)
+        printCoefmat(nu.coef.table, digits = digits, signif.stars = TRUE)
+        #print.default(nu.coef.table, digits = digits, print.gap = 2,  quote = FALSE)
         cat("\n")
         }
         else
@@ -317,9 +358,13 @@ else
             else
                 cat("Nu is equal with the vector (", object$nu.fv[1], ",",object$nu.fv[2], ",",object$nu.fv[3], ",",object$nu.fv[4], ", ...) \n")
             }
+         coef.table <- rbind(mu.coef.table, sigma.coef.table, nu.coef.table)     
     }
+
     if ("tau"%in%object$parameters) 
    {
+      ifWarning[4]  <- (!is.null(unlist(attr(terms(formula(object, "tau"), 
+                             specials = .gamlss.sm.list), "specials")))) 
          if (object$tau.df != 0)   
         {
                      Qr <- object$tau.qr 
@@ -335,7 +380,8 @@ else
         cat("Tau link function: ", object$tau.link,"\n")
         cat("Tau Coefficients:")
         cat("\n")
-        print.default(tau.coef.table, digits = digits, print.gap = 2,  quote = FALSE)
+        printCoefmat(tau.coef.table, digits = digits, signif.stars = TRUE)
+        #print.default(tau.coef.table, digits = digits, print.gap = 2,  quote = FALSE)
         cat("\n")
         }
         else
@@ -348,7 +394,16 @@ else
             else
                 cat("Tau is equal with the vector (", object$tau.fv[1], ",",object$tau.fv[2], ",",object$tau.fv[3], ",",object$tau.fv[4], ", ...) \n")
             }
+         coef.table <- rbind(mu.coef.table, sigma.coef.table, nu.coef.table, tau.coef.table)    
    }
+if (any(ifWarning))
+{
+  cat("-------------------------------------------------------------------\n")
+  cat("NOTE: Additive smoothing terms exist in the formulas: \n")
+  cat(" i) Std. Error for smoothers are for the linear effect only. \n")
+  cat("ii) Std. Error for the linear terms may not be reliable. \n")
+}
+
    cat("-------------------------------------------------------------------\n")
    cat("No. of observations in the fit: ", object$noObs, "\n")
    cat("Degrees of Freedom for the fit: ", object$df.fit)
@@ -360,12 +415,14 @@ else
         "\n            SBC:    ",object$sbc, "\n") #format(signif(object$sbc, digits)), "\n")
     cat("*******************************************************************")
     cat("\n")
+    
   }
  if ( save == TRUE)
     {
       out <- as.list(environment())
        return(out)
   }
+invisible(coef.table)
 }
  
 #==============================================================================
